@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -28,9 +28,11 @@ import javax.servlet.http.HttpServletResponse;
 import com.openexchange.caldav.clientfields.Lightning;
 import com.openexchange.caldav.resources.EventResource;
 import com.openexchange.chronos.Calendar;
+import com.openexchange.chronos.CalendarObjectResource;
 import com.openexchange.chronos.Event;
 import com.openexchange.chronos.ExtendedProperty;
 import com.openexchange.chronos.common.CalendarUtils;
+import com.openexchange.chronos.common.DefaultCalendarObjectResource;
 import com.openexchange.chronos.ical.ICalParameters;
 import com.openexchange.chronos.ical.ICalService;
 import com.openexchange.chronos.ical.ImportedCalendar;
@@ -41,6 +43,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.java.Strings;
 import com.openexchange.java.util.TimeZones;
 import com.openexchange.webdav.protocol.WebdavPath;
+import com.openexchange.webdav.protocol.WebdavProtocolException;
 
 /**
  * {@link CalDAVImport}
@@ -104,6 +107,14 @@ public class CalDAVImport {
                 LOG.debug("Skipping event marked with \"{}\": {}", Lightning.X_MOZ_FAKED_MASTER.getId(), importedEvent);
                 continue;
             }
+            /*
+             * take over first or check consecutive event UID
+             */
+            if (null == uid) {
+                uid = importedEvent.getUid();
+            } else if (false == uid.equals(importedEvent.getUid())) {
+                throw new PreconditionException(DAVProtocol.CAL_NS.getURI(), "valid-calendar-object-resource", url, HttpServletResponse.SC_FORBIDDEN);
+            }
             if (looksLikeException(importedEvent)) {
                 /*
                  * take over change exception event
@@ -113,7 +124,7 @@ public class CalDAVImport {
                 /*
                  * check against min-/max-date-time, if configured
                  */
-                if (Boolean.valueOf(resource.getFactory().getConfigValue("com.openexchange.caldav.interval.strict", "false"))) {
+                if (Boolean.parseBoolean(resource.getFactory().getConfigValue("com.openexchange.caldav.interval.strict", "false"))) {
                     if (false == CalendarUtils.isInRange(importedEvent, resource.getParent().getMinDateTime(), null, TimeZones.UTC) && (
                         null == importedEvent.getRecurrenceRule() || false == resource.getFactory().requireService(RecurrenceService.class).iterateEventOccurrences(
                             importedEvent, resource.getParent().getMinDateTime(), null).hasNext())) {
@@ -123,11 +134,6 @@ public class CalDAVImport {
                         throw new PreconditionException(DAVProtocol.CAL_NS.getURI(), "max-date-time", url, HttpServletResponse.SC_FORBIDDEN);
                     }
                 }
-                if (null == uid) {
-                    uid = importedEvent.getUid();
-                } else if (false == uid.equals(importedEvent.getUid())) {
-                    throw new PreconditionException(DAVProtocol.CAL_NS.getURI(), "valid-calendar-object-resource", url, HttpServletResponse.SC_FORBIDDEN);
-                }
                 /*
                  * take over series master or non-recurring event
                  */
@@ -203,6 +209,34 @@ public class CalDAVImport {
         return changeExceptions;
     }
 
+    /**
+     * Initializes a new calendar object resource bundling the imported event data.
+     * 
+     * @return The calendar object resource
+     * @throws WebdavProtocolException <code>CALDAV:valid-calendar-object-resource</code> precondition exception if no valid calendar object resource can be created
+     */
+    public CalendarObjectResource asCalendarObjectResource() throws WebdavProtocolException {
+        try {
+            return new DefaultCalendarObjectResource(event, changeExceptions);
+        } catch (IllegalArgumentException e) {
+            throw new PreconditionException(OXException.general("", e), DAVProtocol.CAL_NS.getURI(), "valid-calendar-object-resource", url, HttpServletResponse.SC_FORBIDDEN);
+        }
+    }
+
+    /**
+     * Gets all imported events.
+     *
+     * @return The events, or an empty list if there are none.
+     */
+    public List<Event> getEvents() {
+        List<Event> events = new ArrayList<Event>(changeExceptions.size() + 1);
+        if (null != event) {
+            events.add(event);
+        }
+        events.addAll(changeExceptions);
+        return events;
+    }
+
     private static boolean looksLikeException(Event event) {
         return null != event.getRecurrenceId();
     }
