@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -32,6 +32,7 @@ import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.Folder;
+import com.openexchange.folderstorage.UsedForSync;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.userconfiguration.Permission;
 import com.openexchange.server.ServiceLookup;
@@ -104,8 +105,9 @@ public class CalDAVURLField implements AdditionalFolderField {
         try {
             ConfigView view = requireService(ConfigViewFactory.class, services).getView(session.getUserId(), session.getContextId());
             ComposedConfigProperty<String> property = view.property("com.openexchange.caldav.url", String.class);
-            if (null != property && property.isDefined()) {
-                return property.get();
+            if (null != property) {
+                String value = property.get();
+                return value == null ? defaultValue : value;
             }
         } catch (OXException e) {
             org.slf4j.LoggerFactory.getLogger(CalDAVURLField.class).warn("Error getting property \"com.openexchange.caldav.url\", falling back to {}.", defaultValue, e);
@@ -118,6 +120,10 @@ public class CalDAVURLField implements AdditionalFolderField {
         if (null == contentType) {
             return null;
         }
+        UsedForSync usedForSync = folder.getUsedForSync();
+        if (null != usedForSync && false == usedForSync.isUsedForSync()) {
+            return null;
+        }
         switch (contentType.getModule()) {
             case FolderObject.CALENDAR:
                 if (false == session.getUserConfiguration().hasCalendar() || false == session.getUserConfiguration().hasPermission(Permission.CALDAV)) {
