@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,9 +21,10 @@
 
 package com.openexchange.caldav;
 
-import static com.openexchange.chronos.common.CalendarUtils.*;
+import static com.openexchange.chronos.common.CalendarUtils.addExtendedProperty;
 import static com.openexchange.chronos.common.CalendarUtils.find;
 import static com.openexchange.chronos.common.CalendarUtils.getEventID;
+import static com.openexchange.chronos.common.CalendarUtils.isAttendeeSchedulingResource;
 import static com.openexchange.chronos.common.CalendarUtils.isGroupScheduled;
 import static com.openexchange.chronos.common.CalendarUtils.isOpaqueTransparency;
 import static com.openexchange.chronos.common.CalendarUtils.isOrganizer;
@@ -154,7 +155,7 @@ public class EventPatches {
     public static ICalParameters applyIgnoredProperties(EventResource resource, ICalParameters parameters) {
         if (null != parameters) {
             DAVUserAgent userAgent = resource.getUserAgent();
-            if (false == DAVUserAgent.EM_CLIENT.equals(userAgent) && false == DAVUserAgent.EM_CLIENT_FOR_APPSUITE.equals(userAgent)) {
+            if (false == DAVUserAgent.EM_CLIENT.equals(userAgent)) {
                 /*
                  * forcibly ignore X-MICROSOFT-CDO-ALLDAYEVENT and X-MICROSOFT-CDO-BUSYSTATUS for clients other than em client
                  */
@@ -373,8 +374,7 @@ public class EventPatches {
                  */
                 adjustMozillaLastAcknowledged(importedEvent, importedSeriesMaster, calendar);
             }
-            if (DAVUserAgent.THUNDERBIRD_LIGHTNING.equals(resource.getUserAgent()) || DAVUserAgent.EM_CLIENT.equals(resource.getUserAgent())||
-                DAVUserAgent.EM_CLIENT_FOR_APPSUITE.equals(resource.getUserAgent())) {
+            if (DAVUserAgent.THUNDERBIRD_LIGHTNING.equals(resource.getUserAgent()) || DAVUserAgent.EM_CLIENT.equals(resource.getUserAgent())) {
                 /*
                  * handle snoozing via X-MOZ-SNOOZE and X-MOZ-SNOOZE-TIME-...
                  */
@@ -443,8 +443,8 @@ public class EventPatches {
                             EventUpdate eventUpdate = DefaultEventUpdate.builder()
                                 .originalEvent(originalOccurrence)
                                 .updatedEvent(newChangeException)
-                                .ignoredEventFields(EventField.TIMESTAMP, EventField.LAST_MODIFIED, EventField.SEQUENCE, EventField.RECURRENCE_RULE, EventField.RECURRENCE_ID, EventField.CREATED, EventField.EXTENDED_PROPERTIES)
-                                .ignoredEventFields(AttendeeField.TIMESTAMP)
+                                .ignoredEventFields(EventField.TIMESTAMP, EventField.LAST_MODIFIED, EventField.SEQUENCE, EventField.RECURRENCE_RULE, EventField.RECURRENCE_ID, EventField.CREATED, EventField.EXTENDED_PROPERTIES, EventField.DTSTAMP)
+                                .ignoredEventFields(AttendeeField.TIMESTAMP, AttendeeField.SEQUENCE)
                                 .considerUnset(true)
                                 .ignoreDefaults(true)
                             .build();
@@ -657,6 +657,23 @@ public class EventPatches {
             }
         }
 
+        /**
+         * Removes all <code>X-LIC-ERROR</code> properties that may have been inserted by Mozilla/Lightning from the imported event, as well as its alarm components.
+         * 
+         * @param resource The event resource
+         * @param importedEvent The event being imported
+         */
+        private static void removeMozillaParserErrors(EventResource resource, Event importedEvent) {
+            if (DAVUserAgent.THUNDERBIRD_LIGHTNING.equals(resource.getUserAgent())) {
+                removeExtendedProperties(importedEvent.getExtendedProperties(), Lightning.X_LIC_ERROR.getId());
+                if (null != importedEvent.getAlarms()) {
+                    for (Alarm alarm : importedEvent.getAlarms()) {
+                        removeExtendedProperties(alarm.getExtendedProperties(), Lightning.X_LIC_ERROR.getId());
+                    }
+                }
+            }
+        }
+
         /**
          * Takes over a filename from the parent resource's WebDAV path in case it differs from the event's UID.
          *
@@ -1055,6 +1072,7 @@ public class EventPatches {
                 applyFilename(resource, importedEvent);
                 adjustAttendeeComments(resource, importedEvent);
                 adjustProposedTimePrefixes(importedEvent);
+                removeMozillaParserErrors(resource, importedEvent);
                 restoreDeclinedDeleteExceptions(resource, importedEvent, importedChangeExceptions);
                 restoreAttendeeForOrganizer(resource, importedEvent, importedChangeExceptions);
                 adjustSnoozeExceptions(resource, importedEvent, importedChangeExceptions);
@@ -1071,8 +1089,10 @@ public class EventPatches {
                  * patch the change exceptions
                  */
                 for (Event importedChangeException : importedChangeExceptions) {
+                    applyFilename(resource, importedChangeException);
                     adjustAttendeeComments(resource, importedChangeException);
                     adjustProposedTimePrefixes(importedChangeException);
+                    removeMozillaParserErrors(resource, importedChangeException);
                     adjustAlarms(resource, importedChangeException, importedEvent, caldavImport.getCalender());
                     adjustAppleTravelAdvisory(resource, importedEvent);
                     applyManagedAttachments(importedChangeException, factory.getConfigViewFactory());
@@ -1370,6 +1390,7 @@ public class EventPatches {
             fake.setLastModified(phantom.getLastModified());
             fake.setCreated(phantom.getCreated());
             fake.setTimestamp(phantom.getTimestamp());
+            fake.setDtStamp(phantom.getDtStamp());
             SortedSet<RecurrenceId> recurrenceIds = CalendarUtils.getRecurrenceIds(exportedEvents);
             fake.setRecurrenceDates(recurrenceIds);
             fake.setStartDate(recurrenceIds.first().getValue());
