@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -220,10 +220,11 @@ public class GroupwareCaldavFactory extends DAVFactory {
     public String getConfigValue(String key, String defaultValue) throws OXException {
         ConfigView view = requireService(ConfigViewFactory.class).getView(getUser().getId(), getContext().getContextId());
         ComposedConfigProperty<String> property = view.property(key, String.class);
-        if (null == property || false == property.isDefined()) {
+        if (null == property) {
             return defaultValue;
         }
-        return property.get();
+        String value = property.get();
+        return value == null ? defaultValue : value;
     }
 
     public TasksSQLInterface getTaskInterface() {
@@ -245,7 +246,7 @@ public class GroupwareCaldavFactory extends DAVFactory {
     public User resolveUser(int userID) throws OXException {
         return users.getUser(userID, getContext());
     }
-    
+
     public ConfigViewFactory getConfigViewFactory() {
         return configViewFactory;
     }
