@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -60,17 +60,22 @@ public class PhantomMaster extends Event {
             SortedSet<RecurrenceId> changeExceptionDates = new TreeSet<RecurrenceId>();
             Date lastModified = occurrence.getLastModified();
             long timestamp = occurrence.getTimestamp();
+            long dtStamp = occurrence.getDtStamp();
             for (Event event : detachedOccurrences) {
                 lastModified = Tools.getLatestModified(lastModified, event);
                 if (timestamp < event.getTimestamp()) {
                     timestamp = event.getTimestamp();
                 }
+                if (dtStamp < event.getDtStamp()) {
+                    dtStamp = event.getDtStamp();
+                }
                 if (null != event.getRecurrenceId()) {
                     changeExceptionDates.add(event.getRecurrenceId());
                 }
             }
             setLastModified(lastModified);
             setTimestamp(timestamp);
+            setDtStamp(dtStamp);
             setChangeExceptionDates(changeExceptionDates);
         }
     }
