@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -33,7 +33,9 @@ public enum Lightning {
     X_MOZ_FAKED_MASTER("X-MOZ-FAKED-MASTER"),
     X_MOZ_GENERATION("X-MOZ-GENERATION"),
     X_MOZ_SNOOZE("X-MOZ-SNOOZE"),
-    X_MOZ_SNOOZE_TIME("X-MOZ-SNOOZE-TIME");
+    X_MOZ_SNOOZE_TIME("X-MOZ-SNOOZE-TIME"),
+    X_LIC_ERROR("X-LIC-ERROR"),
+    ;
     
     private final String id;
     
