@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 
 package com.openexchange.caldav.mixins;
 
+import com.google.common.xml.XmlEscapers;
 import com.openexchange.caldav.CaldavProtocol;
 import com.openexchange.caldav.GroupwareCaldavFactory;
 import com.openexchange.dav.mixins.PrincipalURL;
@@ -89,7 +90,7 @@ public class Invite extends SingleXMLPropertyMixin {
         String uri;
         if (permission.isGroup()) {
             uri = PrincipalURL.forGroup(permission.getEntity(), factory.getConfigViewFactory());
-            Group group = factory.requireService(GroupService.class).getGroup(factory.getContext(), permission.getEntity());
+            Group group = factory.requireService(GroupService.class).getGroup(factory.getSession(), permission.getEntity());
             commonName = " + " + group.getDisplayName();
         } else {
             uri = PrincipalURL.forUser(permission.getEntity(), factory.getConfigViewFactory());
@@ -104,8 +105,8 @@ public class Invite extends SingleXMLPropertyMixin {
         }
         boolean mailtoPrefix = true; // bug #44264
         return new StringBuilder()
-            .append("<D:href>").append(mailtoPrefix ? "mailto:" : "").append(uri).append("</D:href>")
-            .append("<CS:common-name>").append(commonName).append("</CS:common-name>")
+            .append("<D:href>").append(mailtoPrefix ? "mailto:" : "").append(XmlEscapers.xmlContentEscaper().escape(uri)).append("</D:href>")
+            .append("<CS:common-name>").append(XmlEscapers.xmlContentEscaper().escape(commonName)).append("</CS:common-name>")
         .toString();
     }
 
