@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -259,7 +259,7 @@ public abstract class CalDAVFolderCollection<T> extends FolderCollection<T> impl
     }
 
     private String getStandardFolderDisplayNameTemplate() {
-        String defaultTemplate = "[foldername]";
+        String defaultTemplate = "[owner]";
         ConfigView configView;
         try {
             configView = factory.requireService(ConfigViewFactory.class).getView();
@@ -271,7 +271,7 @@ public abstract class CalDAVFolderCollection<T> extends FolderCollection<T> impl
     }
 
     private String getSharedFolderDisplayNameTemplate() {
-        String defaultTemplate = "[foldername] ([owner])";
+        String defaultTemplate = "[owner]: [foldername]";
         ConfigView configView;
         try {
             configView = factory.requireService(ConfigViewFactory.class).getView();
