@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 package com.openexchange.caldav.resources;
 
 import static com.openexchange.dav.DAVProtocol.protocolException;
+import static javax.servlet.http.HttpServletResponse.SC_FORBIDDEN;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
@@ -39,6 +40,7 @@ import com.openexchange.caldav.GroupwareCaldavFactory;
 import com.openexchange.caldav.PhantomMaster;
 import com.openexchange.caldav.Tools;
 import com.openexchange.caldav.mixins.ScheduleTag;
+import com.openexchange.chronos.CalendarObjectResource;
 import com.openexchange.chronos.CalendarUser;
 import com.openexchange.chronos.CalendarUserType;
 import com.openexchange.chronos.Event;
@@ -46,6 +48,7 @@ import com.openexchange.chronos.common.CalendarUtils;
 import com.openexchange.chronos.ical.CalendarExport;
 import com.openexchange.chronos.ical.ICalParameters;
 import com.openexchange.chronos.ical.ICalService;
+import com.openexchange.chronos.provider.CalendarCapability;
 import com.openexchange.chronos.provider.composition.IDBasedCalendarAccess;
 import com.openexchange.chronos.service.CalendarParameters;
 import com.openexchange.chronos.service.CalendarResult;
@@ -53,6 +56,7 @@ import com.openexchange.chronos.service.EventID;
 import com.openexchange.dav.DAVProtocol;
 import com.openexchange.dav.DAVUserAgent;
 import com.openexchange.dav.PreconditionException;
+import com.openexchange.dav.Privilege;
 import com.openexchange.dav.resources.DAVCollection;
 import com.openexchange.dav.resources.DAVObjectResource;
 import com.openexchange.dav.resources.FolderCollection;
@@ -60,6 +64,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.groupware.notify.hostname.HostData;
 import com.openexchange.java.Charsets;
 import com.openexchange.java.Streams;
+import com.openexchange.java.Strings;
 import com.openexchange.user.User;
 import com.openexchange.user.UserService;
 import com.openexchange.webdav.protocol.WebdavPath;
@@ -325,13 +330,20 @@ public class EventResource extends DAVObjectResource<Event> {
                 if (null != calendarUser) {
                     stringBuilder.append("<D:href>").append(escaper.escape(calendarUser.getUri())).append("</D:href>");
                     if (CalendarUtils.isInternal(calendarUser, CalendarUserType.INDIVIDUAL)) {
+                        User user = null;
                         try {
-                            User user = factory.getService(UserService.class).getUser(calendarUser.getEntity(), factory.getContext());
-                            stringBuilder.append("<CS:first-name>").append(escaper.escape(user.getGivenName())).append("</CS:first-name>")
-                                .append("<CS:last-name>").append(escaper.escape(user.getSurname())).append("</CS:last-name>");
+                            user = factory.getService(UserService.class).getUser(calendarUser.getEntity(), factory.getContext());
                         } catch (OXException e) {
                             LOG.warn("error resolving user '{}'", calendarUser, e);
                         }
+                        if (null != user) {
+                            if (Strings.isNotEmpty(user.getGivenName())) {
+                                stringBuilder.append("<CS:first-name>").append(escaper.escape(user.getGivenName())).append("</CS:first-name>");
+                            }
+                            if (Strings.isNotEmpty(user.getSurname())) {
+                                stringBuilder.append("<CS:last-name>").append(escaper.escape(user.getSurname())).append("</CS:last-name>");
+                            }
+                        }
                     }
                 }
                 if (null != timestamp) {
@@ -376,8 +388,14 @@ public class EventResource extends DAVObjectResource<Event> {
 
     @Override
     public void create() throws WebdavProtocolException {
+        if (false == parent.supports(CalendarCapability.PERMISSIONS.getName())) {
+            parent.requirePrivilege(Privilege.BIND);
+        }
+        if (exists()) {
+            throw protocolException(getUrl(), HttpServletResponse.SC_CONFLICT);
+        }
         try {
-            createEvent(caldavImport);
+            putEvents(caldavImport);
         } catch (OXException e) {
             throw getProtocolException(e);
         }
@@ -385,6 +403,9 @@ public class EventResource extends DAVObjectResource<Event> {
 
     @Override
     public void delete() throws WebdavProtocolException {
+        if (false == parent.supports(CalendarCapability.PERMISSIONS.getName())) {
+            parent.requirePrivilege(Privilege.UNBIND);
+        }
         try {
             deleteEvent(object);
         } catch (OXException e) {
@@ -394,8 +415,14 @@ public class EventResource extends DAVObjectResource<Event> {
 
     @Override
     public void save() throws WebdavProtocolException {
+        if (false == parent.supports(CalendarCapability.PERMISSIONS.getName())) {
+            parent.requirePrivilege(Privilege.WRITE);
+        }
+        if (false == exists()) {
+            throw protocolException(getUrl(), HttpServletResponse.SC_NOT_FOUND);
+        }
         try {
-            updateEvent(caldavImport);
+            putEvents(caldavImport);
         } catch (OXException e) {
             throw getProtocolException(e);
         }
@@ -427,6 +454,25 @@ public class EventResource extends DAVObjectResource<Event> {
         }.execute(factory.getSession());
     }
 
+    private CalendarResult putEvents(CalDAVImport caldavImport) throws OXException {
+        /*
+         * add imported event(s) to calendar
+         */
+        if (null == caldavImport.getEvent() && caldavImport.getChangeExceptions().isEmpty()) {
+            throw new PreconditionException(DAVProtocol.CAL_NS.getURI(), "valid-calendar-object-resource", url, SC_FORBIDDEN);
+        }
+        CalDAVImport patchedImport = EventPatches.Incoming(parent.getFactory()).applyAll(this, caldavImport);
+        CalendarObjectResource resource = patchedImport.asCalendarObjectResource();
+        boolean replace = null == patchedImport.getEvent(); // do replace if resource consists of change exceptions only 
+        return new CalendarAccessOperation<CalendarResult>(factory) {
+
+            @Override
+            protected CalendarResult perform(IDBasedCalendarAccess access) throws OXException {
+                return access.putResource(parent.folderID, resource, replace);
+            }
+        }.execute(factory.getSession());
+    }
+
     private void updateEvent(CalDAVImport caldavImport) throws OXException {
         if (false == exists()) {
             throw protocolException(getUrl(), HttpServletResponse.SC_NOT_FOUND);
@@ -442,6 +488,7 @@ public class EventResource extends DAVObjectResource<Event> {
                      * update event
                      */
                     EventID eventID = new EventID(parent.folderID, object.getId());
+
                     CalendarResult result = access.updateEvent(eventID, patchedImport.getEvent(), clientTimestamp);
                     if (result.getUpdates().isEmpty()) {
                         LOG.debug("{}: Master event {} not updated.", getUrl(), eventID);
@@ -466,45 +513,6 @@ public class EventResource extends DAVObjectResource<Event> {
         }.execute(factory.getSession());
     }
 
-    private Event createEvent(CalDAVImport caldavImport) throws OXException {
-        if (exists()) {
-            throw protocolException(getUrl(), HttpServletResponse.SC_CONFLICT);
-        }
-        if (null == caldavImport.getEvent()) {
-            throw new PreconditionException(DAVProtocol.CAL_NS.getURI(), "valid-calendar-object-resource", url, HttpServletResponse.SC_FORBIDDEN);
-        }
-        /*
-         * create event
-         */
-        CalDAVImport patchedImport = EventPatches.Incoming(parent.getFactory()).applyAll(this, caldavImport);
-        return new CalendarAccessOperation<Event>(factory) {
-
-            @Override
-            protected Event perform(IDBasedCalendarAccess access) throws OXException {
-                CalendarResult result = access.createEvent(parent.folderID, patchedImport.getEvent());
-                if (result.getCreations().isEmpty()) {
-                    LOG.warn("{}: No event created.", getUrl());
-                    throw new PreconditionException(DAVProtocol.CAL_NS.getURI(), "valid-calendar-object-resource", url, HttpServletResponse.SC_FORBIDDEN);
-                }
-                Event createdEvent = result.getCreations().get(0).getCreatedEvent();
-                long clientTimestamp = result.getTimestamp();
-                /*
-                 * create exceptions
-                 */
-                for (Event changeException : patchedImport.getChangeExceptions()) {
-                    EventID eventID = new EventID(createdEvent.getFolderId(), createdEvent.getId(), changeException.getRecurrenceId());
-                    result = access.updateEvent(eventID, changeException, clientTimestamp);
-                    if (result.getCreations().isEmpty()) {
-                        LOG.warn("{}: No exception created.", getUrl());
-                        throw new PreconditionException(DAVProtocol.CAL_NS.getURI(), "valid-calendar-object-resource", url, HttpServletResponse.SC_FORBIDDEN);
-                    }
-                    clientTimestamp = result.getTimestamp();
-                }
-                return createdEvent;
-            }
-        }.execute(factory.getSession());
-    }
-
     /**
      * Gets an appropriate WebDAV protocol exception for the supplied OX exception.
      *
