@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -39,6 +39,7 @@ import org.jdom2.output.XMLOutputter;
 import com.openexchange.caldav.GroupwareCaldavFactory;
 import com.openexchange.caldav.mixins.ScheduleOutboxURL;
 import com.openexchange.chronos.Attendee;
+import com.openexchange.chronos.ExtendedProperties;
 import com.openexchange.chronos.FreeBusyData;
 import com.openexchange.chronos.FreeBusyTime;
 import com.openexchange.chronos.ical.CalendarExport;
@@ -47,6 +48,7 @@ import com.openexchange.chronos.ical.ICalParameters;
 import com.openexchange.chronos.ical.ICalService;
 import com.openexchange.chronos.ical.ImportedCalendar;
 import com.openexchange.chronos.provider.composition.IDBasedCalendarAccess;
+import com.openexchange.chronos.service.CalendarParameters;
 import com.openexchange.chronos.service.FreeBusyResult;
 import com.openexchange.dav.DAVProtocol;
 import com.openexchange.dav.resources.DAVCollection;
@@ -56,6 +58,7 @@ import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.Permissions;
 import com.openexchange.java.Charsets;
 import com.openexchange.java.Streams;
+import com.openexchange.java.Strings;
 import com.openexchange.webdav.protocol.Protocol;
 import com.openexchange.webdav.protocol.Protocol.Property;
 import com.openexchange.webdav.protocol.WebdavPath;
@@ -71,7 +74,9 @@ import com.openexchange.webdav.protocol.helpers.AbstractResource;
  */
 public class ScheduleOutboxCollection extends DAVCollection {
 
-    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(ScheduleOutboxCollection.class);
+    private static final org.slf4j.Logger LOGGER = org.slf4j.LoggerFactory.getLogger(ScheduleOutboxCollection.class);
+
+    private static final String MASK_UID_PROPERTY = "X-CALENDARSERVER-MASK-UID";
 
     private final GroupwareCaldavFactory factory;
 
@@ -143,11 +148,12 @@ public class ScheduleOutboxCollection extends DAVCollection {
 
                         @Override
                         protected Map<Attendee, FreeBusyResult> perform(IDBasedCalendarAccess access) throws OXException {
-                            return access.queryFreeBusy(freeBusyData.getAttendees(), new Date(freeBusyData.getStartDate().getTimestamp()), new Date(freeBusyData.getEndDate().getTimestamp()), true);
+                            return configureAccess(freeBusyData, access).queryFreeBusy(freeBusyData.getAttendees(), new Date(freeBusyData.getStartDate().getTimestamp()), new Date(freeBusyData.getEndDate().getTimestamp()), true);
                         }
+
                     }.execute(factory.getSession());
                 } catch (OXException e) {
-                    LOG.error("error getting free/busy information", e);
+                    LOGGER.error("error getting free/busy information", e);
                     continue;
                 }
                 for (Attendee attendee : freeBusyData.getAttendees()) {
@@ -158,6 +164,17 @@ public class ScheduleOutboxCollection extends DAVCollection {
         return scheduleResponse;
     }
 
+    protected IDBasedCalendarAccess configureAccess(FreeBusyData freeBusyData, IDBasedCalendarAccess access) {
+        ExtendedProperties extendedProperties = freeBusyData.getExtendedProperties();
+        if (null != extendedProperties && extendedProperties.contains(MASK_UID_PROPERTY)) {
+            Object maskUid = extendedProperties.get(MASK_UID_PROPERTY).getValue();
+            if (null != maskUid && Strings.isNotEmpty(maskUid.toString())) {
+                access.set(CalendarParameters.PARAMETER_MASK_UID, maskUid.toString());
+            }
+        }
+        return access;
+    }
+
     private Element getResponse(FreeBusyData requestedData, Attendee attendee, List<FreeBusyTime> freeBusyTimes) {
         Element response = new Element("response", CAL_NS);
         /*
@@ -188,7 +205,7 @@ public class ScheduleOutboxCollection extends DAVCollection {
                 calendarData.addContent(new CDATA(getVFreeBusyReply(requestedData, attendee, freeBusyTimes)));
                 requestStatus.addContent("2.0;Success");
             } catch (OXException e) {
-                LOG.warn("error getting freebusy", e);
+                LOGGER.warn("error getting freebusy", e);
                 requestStatus.addContent("5.1;Service unavailable");
             }
         }
