@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -101,6 +101,19 @@ public enum CardDAVProperty implements Property {
      * May still be overridden by clients on a per-request basis using the <code>Prefer</code>-header.
      */
     PREFERRED_PHOTO_ENCODING("preferredPhotoEncoding", "binary"),
+    /**
+     * Controls which parent collection / folder is used for newly created contacts created by iOS clients.
+     * <p/>
+     * <p/>
+     * Possible settings are:
+     * <ul>
+     * <li><code>always</code>: New contacts are always created within the user's default contacts folder on App Suite</li>
+     * <li><code>disabled</code>: Contacts are created within the folder targeted by the client, but rejected on insufficient permissions</li>
+     * <li><code>insufficient_permissions</code>: Contacts are created within the folder targeted by the client, falling back to the user's default folder on insufficient permissions</li>
+     * </ul>
+     * Defaults to 'always' so that contacts are created in the user's default contacts folder independently of which folder is targeted by the client.
+     */
+    IOS_FALLBACK_TO_DEFAULT_COLLECTION_FOR_NEW_RESOURCES("iosFallbackToDefaultCollectionForNewResources", "always"),
     ;
 
     private final Object defaultValue;
