@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -23,6 +23,8 @@ package com.openexchange.carddav;
 
 import java.util.Date;
 import java.util.List;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import com.openexchange.contact.ContactFieldOperand;
 import com.openexchange.dav.DAVOAuthScope;
 import com.openexchange.exception.OXException;
@@ -48,6 +50,8 @@ import com.openexchange.webdav.protocol.WebdavPath;
  */
 public class Tools {
 
+    private static final Logger LOG = LoggerFactory.getLogger(Tools.class);
+
     /**
      * The OAuth scope token for CardDAV
      */
@@ -98,6 +102,23 @@ public class Tools {
             result = prime * result + ((null == folder.getID()) ? 0 : folder.getID().hashCode());
             result = prime * result + ((null == folder.getOwnPermission()) ? 0 : folder.getOwnPermission().hashCode());
         }
+
+        if(LOG.isDebugEnabled()) {
+            StringBuilder b = new StringBuilder("Generated folder hash '");
+            b.append(Integer.toHexString(result)).append("' from: ");
+            // @formatter:off
+            folders.forEach((f) -> {
+                b.append("{ name: '")
+                 .append(f.getName())
+                 .append("', id: ")
+                 .append(f.getID())
+                 .append(", perms: ")
+                 .append(f.getOwnPermission().hashCode())
+                 .append(" }, ");
+            });
+            // @formatter:on
+            LOG.debug(b.toString());
+        }
         return Integer.toHexString(result);
     }
 
