@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -134,7 +134,7 @@ public class PhotoResource extends DAVResource {
         try {
             ConfigView view = factory.getService(ConfigViewFactory.class).getView(factory.getUser().getId(), factory.getContext().getContextId());
             ComposedConfigProperty<String> property = view.property("com.openexchange.contact.scaleVCardImages", String.class);
-            String value = property.isDefined() ? property.get() : null;
+            String value = property.get();
             if (Strings.isEmpty(value)) {
                 return null;
             }
