@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -26,7 +26,9 @@ import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Autoboxing.L;
 import java.io.IOException;
 import java.io.InputStream;
+import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.Date;
 import java.util.Enumeration;
 import java.util.HashSet;
@@ -37,6 +39,7 @@ import javax.servlet.http.HttpServletResponse;
 import org.jdom2.Element;
 import com.openexchange.ajax.fileholder.IFileHolder;
 import com.openexchange.carddav.CardDAVProperty;
+import com.openexchange.carddav.DefaultFolderFallbackMode;
 import com.openexchange.carddav.GroupwareCarddavFactory;
 import com.openexchange.carddav.Tools;
 import com.openexchange.carddav.photos.PhotoUtils;
@@ -44,6 +47,7 @@ import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.config.lean.LeanConfigurationService;
 import com.openexchange.contact.ContactFieldOperand;
 import com.openexchange.contact.ContactService;
+import com.openexchange.contact.SortOptions;
 import com.openexchange.contact.storage.ContactTombstoneStorage;
 import com.openexchange.contact.vcard.DistributionListMode;
 import com.openexchange.contact.vcard.VCardExport;
@@ -57,12 +61,14 @@ import com.openexchange.dav.PreconditionException;
 import com.openexchange.dav.resources.CommonResource;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
+import com.openexchange.folderstorage.Permission;
 import com.openexchange.groupware.contact.helpers.ContactField;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.container.DistributionListEntryObject;
 import com.openexchange.groupware.tools.mappings.MappedIncorrectString;
 import com.openexchange.groupware.tools.mappings.MappedTruncation;
 import com.openexchange.java.Charsets;
+import com.openexchange.java.Enums;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
 import com.openexchange.search.CompositeSearchTerm;
@@ -291,17 +297,16 @@ public class ContactResource extends CommonResource<Contact> {
                 }
             }
             contact.setContextId(session.getContextId());
-            String parentFolderID = parent.getFolder().getID();
-            if (DAVUserAgent.IOS.equals(getUserAgent()) && false == parentFolderID.equals(factory.getState().getDefaultFolder().getID())) {
-                /*
-                 * for iOS, set initial parent to the default contacts folder & insert tombstone record for automatic cleanup during next sync
-                 */
+            /*
+             * select initial parent folder & insert tombstone record for automatic cleanup during next sync if different from targeted one
+             */
+            String parentFolderID = selectParentFolderOnCreate();
+            if (false == parentFolderID.equals(parent.getFolder().getID())) {
                 ContactTombstoneStorage tombstoneStorage = factory.getOptionalService(ContactTombstoneStorage.class);
-                if (null != tombstoneStorage && tombstoneStorage.supports(session, parentFolderID)) {
+                if (null != tombstoneStorage && tombstoneStorage.supports(session, parent.getFolder().getID())) {
                     LOG.debug("{}: Re-routing contact creation to default folder for iOS client, inserting tombstone in targeted folder for client recovery.", getUrl());
-                    tombstoneStorage.insertTombstone(session, parentFolderID, contact);
+                    tombstoneStorage.insertTombstone(session, parent.getFolder().getID(), contact);
                 }
-                parentFolderID = factory.getState().getDefaultFolder().getID();
             }
             if (contact.getMarkAsDistribtuionlist() && false == parent.isSyncDistributionLists()) {
                 /*
@@ -356,15 +361,58 @@ public class ContactResource extends CommonResource<Contact> {
         }
     }
 
+    /**
+     * Determines the parent folder to use for a newly created contact resource, which is usually the targeted parent folder, yet may be 
+     * the default contacts folder of the user under certain circumstances. 
+     * 
+     * @return The parent folder identifier to use
+     */
+    private String selectParentFolderOnCreate() throws OXException {
+        String parentFolderID = parent.getFolder().getID();
+        String defaultFolderID = factory.getState().getDefaultFolder().getID();
+        if (parentFolderID.equals(defaultFolderID) || false == DAVUserAgent.IOS.equals(getUserAgent())) {
+            /*
+             * no special handling, use targeted folder as-is
+             */
+            return parentFolderID;
+        }
+        Session session = factory.getSession();
+        LeanConfigurationService configService = factory.getServiceSafe(LeanConfigurationService.class);
+        String value = configService.getProperty(session.getUserId(), session.getContextId(), CardDAVProperty.IOS_FALLBACK_TO_DEFAULT_COLLECTION_FOR_NEW_RESOURCES);
+        switch (Enums.parse(DefaultFolderFallbackMode.class, value, DefaultFolderFallbackMode.ALWAYS)) {
+            case DISABLED:
+                /*
+                 * always use targeted folder as-is
+                 */
+                return parentFolderID;
+            case INSUFFICIENT_PERMISSIONS:
+                /*
+                 * use targeted folder if permissions are sufficient, otherwise fall-through
+                 */
+                if (Permission.CREATE_OBJECTS_IN_FOLDER <= parent.getFolder().getOwnPermission().getFolderPermission()) {
+                    return parentFolderID;
+                }
+            case ALWAYS:
+            default:
+                /*
+                 * fallback to default contacts folder, otherwise
+                 */
+                return defaultFolderID;
+        }
+    }
+
     private void restoreDistributionListReferences(Session session, ContactService contactService, Contact contact, String parentFolderID) throws OXException {
         if (contact == null || !contact.getMarkAsDistribtuionlist()) {
             return;
         }
         // try to search for known contacts
-        SearchTerm<?> searchTerm = createSearchTerm(parentFolderID, Arrays.asList(contact.getDistributionList()), contact.getUid());
+        SearchTerm<?> searchTerm = createSearchTerm(contact.getDistributionList(), contact.getUid());
+        if (null == searchTerm) {
+            return;
+        }
         SearchIterator<Contact> contacts = null;
         try {
-            contacts = contactService.searchContacts(session, searchTerm, CONTACT_FIELDS_TO_LOAD);
+            contacts = contactService.searchContacts(session, Collections.singletonList(parentFolderID), searchTerm, CONTACT_FIELDS_TO_LOAD, SortOptions.EMPTY);
             List<Contact> dbContacts = SearchIterators.asList(contacts);
             Optional<Contact> originalContact = dbContacts.stream().filter(x -> x.getUid().equals(contact.getUid())).findFirst();
             List<DistributionListEntryObject> prepared = restoreDistributionListReferences0(originalContact, Arrays.asList(contact.getDistributionList()), dbContacts);
@@ -374,40 +422,31 @@ public class ContactResource extends CommonResource<Contact> {
         }
     }
 
-    private SearchTerm<?> createSearchTerm(String parentFolderID, List<DistributionListEntryObject> newDistList, String originalContactUID) {
-        SingleSearchTerm folderTerm = new SingleSearchTerm(SingleOperation.EQUALS);
-        folderTerm.addOperand(new ContactFieldOperand(ContactField.FOLDER_ID));
-        folderTerm.addOperand(new ConstantOperand<String>(parentFolderID));
-
-        CompositeSearchTerm uidOrTerm = null;
-        for (DistributionListEntryObject entry : newDistList) {
-            String uid = entry.getContactUid();
-            if (Strings.isNotEmpty(uid)) {
-                if (uidOrTerm == null) {
-                    uidOrTerm = new CompositeSearchTerm(CompositeOperation.OR);
+    private SearchTerm<?> createSearchTerm(DistributionListEntryObject[] newDistList, String originalContactUID) {
+        List<SingleSearchTerm> uidTerms = new ArrayList<SingleSearchTerm>();
+        if (Strings.isNotEmpty(originalContactUID)) {
+            uidTerms.add(new SingleSearchTerm(SingleOperation.EQUALS)
+                .addOperand(new ContactFieldOperand(ContactField.UID)).addOperand(new ConstantOperand<String>(originalContactUID)));
+        }
+        if (null != newDistList) {
+            for (DistributionListEntryObject entry : newDistList) {
+                if (Strings.isNotEmpty(entry.getContactUid())) {
+                    uidTerms.add(new SingleSearchTerm(SingleOperation.EQUALS)
+                        .addOperand(new ContactFieldOperand(ContactField.UID)).addOperand(new ConstantOperand<String>(entry.getContactUid())));
                 }
-                SingleSearchTerm uidTerm = new SingleSearchTerm(SingleOperation.EQUALS);
-                uidTerm.addOperand(new ContactFieldOperand(ContactField.UID));
-                uidTerm.addOperand(new ConstantOperand<String>(uid));
-                uidOrTerm.addSearchTerm(uidTerm);
             }
         }
-        SearchTerm<?> searchTerm = null;
-        if (uidOrTerm != null) {
-            if (Strings.isNotEmpty(originalContactUID)) {
-                SingleSearchTerm uidTerm = new SingleSearchTerm(SingleOperation.EQUALS);
-                uidTerm.addOperand(new ContactFieldOperand(ContactField.UID));
-                uidTerm.addOperand(new ConstantOperand<String>(originalContactUID));
-                uidOrTerm.addSearchTerm(uidTerm);
-            }
-            CompositeSearchTerm compSearchTerm = new CompositeSearchTerm(CompositeOperation.AND);
-            compSearchTerm.addSearchTerm(folderTerm);
-            compSearchTerm.addSearchTerm(uidOrTerm);
-            searchTerm = compSearchTerm;
-        } else {
-            searchTerm = folderTerm;
+        if (uidTerms.isEmpty()) {
+            return null;
         }
-        return searchTerm;
+        if (1 == uidTerms.size()) {
+            return uidTerms.get(0);
+        }
+        CompositeSearchTerm orTerm = new CompositeSearchTerm(CompositeOperation.OR);
+        for (SingleSearchTerm uidTerm : uidTerms) {
+            orTerm.addSearchTerm(uidTerm);
+        }
+        return orTerm;
     }
 
     private List<DistributionListEntryObject> restoreDistributionListReferences0(Optional<Contact> originalContact, List<DistributionListEntryObject> provided, List<Contact> dbContacts) {
@@ -449,11 +488,11 @@ public class ContactResource extends CommonResource<Contact> {
                         LOG.warn("Unexpected error assigning default mail address from reference contact", e);
                     }
                 }
-                if (!entry.containsEntryID() || entry.getEntryID() < 1) {
-                    entry.setEntryID(dbContact.getObjectID());
+                if (!entry.containsEntryID() || entry.getEntryID() == null) {
+                    entry.setEntryID(dbContact.getId(true));
                 }
-                if (!entry.containsFolderld() || entry.getFolderID() < 1) {
-                    entry.setFolderID(dbContact.getParentFolderID());
+                if (!entry.containsFolderld() || entry.getFolderID() == null) {
+                    entry.setFolderID(dbContact.getFolderId(true));
                 }
             } else if (originalContact.isPresent()) {
                 // try to match dleo from original list
