@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -27,6 +27,7 @@ import static com.openexchange.java.Autoboxing.I;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
+import java.util.concurrent.atomic.AtomicReference;
 import java.util.regex.Pattern;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.carddav.AggregatedCollectionMode;
@@ -45,6 +46,8 @@ import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.folderstorage.database.contentType.ContactsContentType;
 import com.openexchange.groupware.container.CommonObject;
 import com.openexchange.java.Enums;
+import com.openexchange.java.ImmutableReference;
+import com.openexchange.java.MatcherWatcher;
 import com.openexchange.java.Strings;
 import com.openexchange.login.Interface;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
@@ -60,7 +63,7 @@ public class RootCollection extends DAVRootCollection {
     private final GroupwareCarddavFactory factory;
 
     private String exposedCollections;
-    private Pattern userAgentForAggregatedCollection;
+    private final AtomicReference<ImmutableReference<Pattern>> userAgentForAggregatedCollectionReference;
     private AggregatedCollectionMode aggregatedCollectionMode;
 
     /**
@@ -69,10 +72,11 @@ public class RootCollection extends DAVRootCollection {
      * @param factory the factory
      */
     public RootCollection(GroupwareCarddavFactory factory) throws WebdavProtocolException {
-    	super(factory, "Addressbooks");
-    	this.factory = factory;
-    	includeProperties(new SyncToken(this));
-    	if (isUseAggregatedCollection()) {
+        super(factory, "Addressbooks");
+        this.factory = factory;
+        this.userAgentForAggregatedCollectionReference = new AtomicReference<>();
+        includeProperties(new SyncToken(this));
+        if (isUseAggregatedCollection()) {
             /*
              * indicate permissions from default folder also for root collection for macOS client
              */
@@ -175,17 +179,29 @@ public class RootCollection extends DAVRootCollection {
     }
 
     private Pattern getUserAgentForAggregatedCollection() {
-        if (null == userAgentForAggregatedCollection) {
-            String regex;
-            try {
-                regex = factory.getServiceSafe(LeanConfigurationService.class).getProperty(CardDAVProperty.USERAGENT_FOR_AGGREGATED_COLLECTION);
-            } catch (OXException e) {
-                regex = CardDAVProperty.USERAGENT_FOR_AGGREGATED_COLLECTION.getDefaultValue(String.class);
-                LOG.error("error getting exposed collections from config, falling back to '{}'", regex, e);
+        ImmutableReference<Pattern> userAgentForAggregatedCollectionRef = userAgentForAggregatedCollectionReference.get();
+        if (null == userAgentForAggregatedCollectionRef) {
+            synchronized (this) {
+                userAgentForAggregatedCollectionRef = userAgentForAggregatedCollectionReference.get();
+                if (null == userAgentForAggregatedCollectionRef) {
+                    String regex;
+                    try {
+                        regex = factory.getServiceSafe(LeanConfigurationService.class).getProperty(CardDAVProperty.USERAGENT_FOR_AGGREGATED_COLLECTION);
+                    } catch (OXException e) {
+                        regex = CardDAVProperty.USERAGENT_FOR_AGGREGATED_COLLECTION.getDefaultValue(String.class);
+                        LOG.error("error getting exposed collections from config, falling back to '{}'", regex, e);
+                    }
+                    try {
+                        userAgentForAggregatedCollectionRef = new ImmutableReference<>(Pattern.compile(regex, Pattern.CASE_INSENSITIVE));
+                    } catch (Exception e) {
+                        LOG.error("error compiling regular expression: '{}'. Using no user-agent matching", regex, e);
+                        userAgentForAggregatedCollectionRef = new ImmutableReference<>(null);
+                    }
+                    userAgentForAggregatedCollectionReference.set(userAgentForAggregatedCollectionRef);
+                }
             }
-            userAgentForAggregatedCollection = Pattern.compile(regex, Pattern.CASE_INSENSITIVE);
         }
-        return userAgentForAggregatedCollection;
+        return userAgentForAggregatedCollectionRef.getValue();
     }
 
 	private boolean isUseAggregatedCollection() {
@@ -196,13 +212,16 @@ public class RootCollection extends DAVRootCollection {
 		return "1".equals(getExposedCollections()) || "0".equals(getExposedCollections()) && false == isAddressbookClient();
 	}
 
-	private boolean isAddressbookClient() {
-		String userAgent = (String)factory.getSession().getParameter("user-agent");
-		if (null != userAgent && 0 < userAgent.length() && null != getUserAgentForAggregatedCollection()) {
-		    return getUserAgentForAggregatedCollection().matcher(userAgent).find();
-		}
-		return false;
-	}
+    private boolean isAddressbookClient() {
+        String userAgent = (String) factory.getSession().getParameter("user-agent");
+        if (Strings.isNotEmpty(userAgent)) {
+            Pattern userAgentForAggregatedCollection = getUserAgentForAggregatedCollection();
+            if (null != userAgentForAggregatedCollection && MatcherWatcher.findSafe(userAgentForAggregatedCollection, userAgent, MatcherWatcher.DEFAULT_REGEX_TIMEOUT)) {
+                return true;
+            }
+        }
+        return false;
+    }
 
     private CardDAVCollection createFolderCollection(UserizedFolder folder) throws WebdavProtocolException {
         try {
