@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -69,8 +69,8 @@ public class CardDAV extends DAVServlet {
          */
         boolean enabled = false;
         try {
-            ComposedConfigProperty<Boolean> enabledProperty = performer.getFactory().requireService(ConfigViewFactory.class).getView(session.getUserId(), session.getContextId()).property("com.openexchange.carddav.enabled", Boolean.class);
-            enabled = enabledProperty.isDefined() && b(enabledProperty.get());
+            Boolean b = performer.getFactory().requireService(ConfigViewFactory.class).getView(session.getUserId(), session.getContextId()).property("com.openexchange.carddav.enabled", Boolean.class).get();
+            enabled = b != null && b(b);
         } catch (OXException e) {
             org.slf4j.LoggerFactory.getLogger(CardDAV.class).warn("Error obtaining 'enabled' property from config-cascade, assuming 'false'.", e);
             return false;
