@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -54,7 +54,6 @@ public class DAVClientInfoProvider implements ClientInfoProvider {
     private static final String IOS_DAV = "ios_calendar/addressbook";
     private static final String THUNDERBIRD_LIGHTNING = "thunderbird_lightning";
     private static final String EMCLIENT = "emclient";
-    private static final String EMCLIENT_APPSUITE = "emclient_appsuite";
     private static final String OX_SYNC = "oxsyncapp";
     private static final String CALDAV_SYNC = "caldav_sync";
     private static final String CARDDAV_SYNC = "carddav_sync";
@@ -70,14 +69,17 @@ public class DAVClientInfoProvider implements ClientInfoProvider {
 
     /**
      * Initializes a new {@link DAVClientInfoProvider}.
+     * 
+     * @param userAgentParser The {@link UserAgentParser}
+     * @param davParser The {@link DAVUserAgentParser}
      */
-    public DAVClientInfoProvider(final UserAgentParser userAgentParser) {
+    public DAVClientInfoProvider(UserAgentParser userAgentParser, DAVUserAgentParser davParser) {
         super();
         CacheLoader<String, DAVClientInfo> loader = new CacheLoader<String, DAVClientInfo>() {
 
             @Override
             public DAVClientInfo load(String sUserAgent) throws Exception {
-                DAVUserAgent userAgent = DAVUserAgent.parse(sUserAgent);
+                DAVUserAgent userAgent = davParser.parse(sUserAgent);
                 String clientFamily = getClientFamily(userAgent);
                 ReadableUserAgent readableUserAgent = userAgentParser.parse(sUserAgent);
                 if (UNKNOWN.equals(clientFamily) && (null == readableUserAgent || UNKNOWN.equalsIgnoreCase(readableUserAgent.getName()))) {
@@ -117,9 +119,6 @@ public class DAVClientInfoProvider implements ClientInfoProvider {
                 if (EMCLIENT.equals(clientFamily)) {
                     client = "eM Client";
                 }
-                if (EMCLIENT_APPSUITE.equals(clientFamily)) {
-                    client = "eM Client for OX App Suite";
-                }
                 String clientVersionMajor = readableUserAgent.getVersionNumber().getMajor();
                 String clientVersionMinor = readableUserAgent.getVersionNumber().getMinor();
                 if (Strings.isNotEmpty(clientVersionMajor)) {
@@ -209,8 +208,6 @@ public class DAVClientInfoProvider implements ClientInfoProvider {
                 return THUNDERBIRD_LIGHTNING;
             case EM_CLIENT:
                 return EMCLIENT;
-            case EM_CLIENT_FOR_APPSUITE:
-                return EMCLIENT_APPSUITE;
             case OX_SYNC:
             case SMOOTH_SYNC:
                 return OX_SYNC;
@@ -251,7 +248,6 @@ public class DAVClientInfoProvider implements ClientInfoProvider {
             case IOS:
                 return "ios";
             case EM_CLIENT:
-            case EM_CLIENT_FOR_APPSUITE:
             case WINDOWS:
                 return "windows";
             case DAVDROID:
