@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -30,6 +30,7 @@ import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
 import com.openexchange.ajax.Client;
 import com.openexchange.ajax.requesthandler.oauth.OAuthConstants;
+import com.openexchange.dav.osgi.Services;
 import com.openexchange.exception.OXException;
 import com.openexchange.framework.request.RequestContextHolder;
 import com.openexchange.java.Strings;
@@ -88,10 +89,9 @@ public class DAVServlet extends OXServlet {
     @Override
     protected LoginRequest parseLoginRequest(Credentials credentials, HttpServletRequest request) {
         String userAgent = request.getHeader("user-agent");
-        DAVUserAgent davUserAgent = DAVUserAgent.parse(userAgent);
-        Interface interfaze = getInterface(davUserAgent);
-        Client client = Interface.CARDDAV.equals(interfaze) ? Client.CARDDAV : Client.CALDAV;
-        LoginRequest loginRequest = new LoginRequestImpl(request, credentials.getLogin(), credentials.getPassword(), interfaze, client.getClientId(), null, userAgent);
+        Interface interfaze = getLoginInterface(userAgent);
+        String client = (Interface.CARDDAV.equals(interfaze) ? Client.CARDDAV : Client.CALDAV).getClientId();
+        LoginRequest loginRequest = new LoginRequestImpl(request, credentials.getLogin(), credentials.getPassword(), interfaze, client, null, userAgent);
         return ALLOW_ASTERISK_LOGIN_CUSTOMIZER.modifyLogin(loginRequest);
     }
 
@@ -100,16 +100,25 @@ public class DAVServlet extends OXServlet {
         return interfaze;
     }
 
-    private Interface getInterface(DAVUserAgent userAgent) {
-        switch (userAgent) {
-            case CARDDAV_SYNC:
-            case MAC_CONTACTS:
-                return Interface.CARDDAV;
-            case UNKNOWN:
-                return getInterface();
-            default:
+    private Interface getLoginInterface(String userAgent) {
+        DAVUserAgentParser userAgentParser = Services.getDAVUserAgentParser();
+        DAVUserAgent davUserAgent = null != userAgentParser ? userAgentParser.parse(userAgent) : DAVUserAgent.UNKNOWN;
+        /*
+         * prefer user-agent-specific client if available
+         */
+        Client clientByUserAgent = davUserAgent.optClientIdentifier();
+        if (null != clientByUserAgent) {
+            if (Client.CALDAV.equals(clientByUserAgent)) {
                 return Interface.CALDAV;
+            }
+            if (Client.CARDDAV.equals(clientByUserAgent)) {
+                return Interface.CARDDAV;
+            }
         }
+        /*
+         * derive client from interface, otherwise
+         */
+        return getInterface();
     }
 
     @Override
