@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -88,7 +88,7 @@ public class Invite extends SingleXMLPropertyMixin {
         String uri;
         if (permission.isGroup()) {
             uri = PrincipalURL.forGroup(permission.getEntity(), configViewFactory);
-            Group group = factory.requireService(GroupService.class).getGroup(factory.getContext(), permission.getEntity());
+            Group group = factory.requireService(GroupService.class).getGroup(factory.getSession(), permission.getEntity());
             commonName = " + " + group.getDisplayName();
         } else {
             uri = PrincipalURL.forUser(permission.getEntity(), configViewFactory);
