@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -25,16 +25,19 @@ import static com.openexchange.dav.DAVTools.getInternalPath;
 import org.osgi.service.http.HttpService;
 import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.clientinfo.ClientInfoProvider;
+import com.openexchange.config.Reloadable;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.contact.ContactService;
 import com.openexchange.dav.DAVClientInfoProvider;
 import com.openexchange.dav.DAVServlet;
+import com.openexchange.dav.DAVUserAgentParser;
 import com.openexchange.dav.attachments.AttachmentPerformer;
 import com.openexchange.dav.mixins.AddressbookHomeSet;
 import com.openexchange.dav.mixins.CalendarHomeSet;
 import com.openexchange.dav.mixins.PrincipalCollectionSet;
 import com.openexchange.dav.principals.PrincipalPerformer;
 import com.openexchange.dav.root.RootPerformer;
+import com.openexchange.dav.useragent.DAVUserAgentParserImpl;
 import com.openexchange.group.GroupService;
 import com.openexchange.login.Interface;
 import com.openexchange.osgi.HousekeepingActivator;
@@ -87,11 +90,22 @@ public class DAVActivator extends HousekeepingActivator {
         registerService(PropertyMixin.class, new PrincipalCollectionSet(configViewFactory));
         registerService(PropertyMixin.class, new CalendarHomeSet(configViewFactory));
         registerService(PropertyMixin.class, new AddressbookHomeSet(configViewFactory));
+        /*
+         * Initialize DAV agents
+         */
+        DAVUserAgentParserImpl parser = new DAVUserAgentParserImpl(this, configViewFactory);
+        registerService(DAVUserAgentParser.class, parser);
+        addService(DAVUserAgentParser.class, parser);
+        registerService(Reloadable.class, parser);
         /*
          * DAV client info
          */
-        registerService(ClientInfoProvider.class, new DAVClientInfoProvider(getService(UserAgentParser.class)), 0);
+        registerService(ClientInfoProvider.class, new DAVClientInfoProvider(getService(UserAgentParser.class), parser), 0);
         openTrackers();
+        /*
+         * Set service lookup
+         */
+        Services.setServiceLookup(this);
     }
 
     @Override
