@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -30,7 +30,7 @@ import com.openexchange.dav.mixins.DisplayName;
 import com.openexchange.dav.mixins.EmailAddressSet;
 import com.openexchange.dav.mixins.PrincipalURL;
 import com.openexchange.dav.mixins.RecordType;
-import com.openexchange.dav.resources.DAVResource;
+import com.openexchange.dav.principals.AbstractPrincipalResource;
 import com.openexchange.resource.Resource;
 import com.openexchange.webdav.protocol.WebdavPath;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
@@ -41,7 +41,7 @@ import com.openexchange.webdav.protocol.WebdavProtocolException;
  * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
  * @since v7.8.1
  */
-public class ResourcePrincipalResource extends DAVResource {
+public class ResourcePrincipalResource extends AbstractPrincipalResource {
 
     private final Resource resource;
 
@@ -63,11 +63,6 @@ public class ResourcePrincipalResource extends DAVResource {
         );
     }
 
-    @Override
-    public String getResourceType() throws WebdavProtocolException {
-        return"<D:resourcetype><D:principal /></D:resourcetype>";
-    }
-
     @Override
     public String getDisplayName() throws WebdavProtocolException {
         return resource.getDisplayName();
