@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -36,7 +36,7 @@ import com.openexchange.dav.mixins.LastName;
 import com.openexchange.dav.mixins.PrincipalCollectionSet;
 import com.openexchange.dav.mixins.PrincipalURL;
 import com.openexchange.dav.mixins.RecordType;
-import com.openexchange.dav.resources.DAVResource;
+import com.openexchange.dav.principals.AbstractPrincipalResource;
 import com.openexchange.user.User;
 import com.openexchange.webdav.protocol.WebdavPath;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
@@ -47,7 +47,7 @@ import com.openexchange.webdav.protocol.WebdavProtocolException;
  * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
  * @since v7.8.1
  */
-public class UserPrincipalResource extends DAVResource {
+public class UserPrincipalResource extends AbstractPrincipalResource {
 
     private final User user;
 
@@ -72,11 +72,6 @@ public class UserPrincipalResource extends DAVResource {
         );
     }
 
-    @Override
-    public String getResourceType() throws WebdavProtocolException {
-        return"<D:resourcetype><D:principal /></D:resourcetype>";
-    }
-
     @Override
     public String getDisplayName() throws WebdavProtocolException {
         return user.getDisplayName();
