@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -36,6 +36,7 @@ import com.openexchange.folderstorage.Permission;
 import com.openexchange.group.Group;
 import com.openexchange.group.GroupService;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.session.Session;
 import com.openexchange.user.User;
 import com.openexchange.user.UserService;
 import com.openexchange.webdav.action.WebdavRequest;
@@ -78,11 +79,12 @@ public class ACLPrincipalPropSet extends PROPFINDAction {
         if (DAVCollection.class.isInstance(request.getCollection())) {
             DAVCollection collection = (DAVCollection) request.getCollection();
             Context context = collection.getFactory().getContext();
+            Session session = collection.getFactory().getSession();
             for (Permission permission : collection.getPermissions()) {
                 try {
                     WebdavResource resource;
                     if (permission.isGroup()) {
-                        Group group = collection.getFactory().requireService(GroupService.class).getGroup(context, permission.getEntity());
+                        Group group = collection.getFactory().requireService(GroupService.class).getGroup(session, permission.getEntity());
                         WebdavPath url = new WebdavPath(PrincipalURL.forGroup(group.getIdentifier(), collection.getFactory().requireService(ConfigViewFactory.class)));
                         resource = new GroupPrincipalResource(collection.getFactory(), group, url);
                     } else {
