@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -223,7 +223,7 @@ public class PrinicpalPropertySearchReport extends PROPFINDAction {
                             int groupID = extractPrincipalID(pattern, CalendarUserType.GROUP, factory);
                             if (-1 != groupID) {
                                 try {
-                                    Group group = factory.getServiceSafe(GroupService.class).getGroup(factory.getContext(), groupID);
+                                    Group group = factory.getServiceSafe(GroupService.class).getGroup(factory.getSession(), groupID);
                                     if (null != group) {
                                         groups.add(group);
                                     }
