@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -26,7 +26,9 @@ import java.util.Date;
 import java.util.List;
 import com.openexchange.dav.DAVFactory;
 import com.openexchange.dav.DAVUserAgent;
+import com.openexchange.dav.DAVUserAgentParser;
 import com.openexchange.dav.mixins.CurrentUserPrincipal;
+import com.openexchange.dav.osgi.Services;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.framework.request.RequestContextHolder;
 import com.openexchange.session.Session;
@@ -85,7 +87,12 @@ public abstract class DAVCollection extends AbstractCollection {
                     value = (String) session.getParameter("user-agent");
                 }
             }
-            userAgent = DAVUserAgent.parse(value);
+            DAVUserAgentParser parser = Services.getDAVUserAgentParser();
+            if (null == parser) {
+                userAgent = DAVUserAgent.UNKNOWN;
+            } else {
+                userAgent = parser.parse(value);
+            }
         }
         return userAgent;
     }
