@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -31,7 +31,9 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map.Entry;
 import java.util.Objects;
+import java.util.Set;
 import javax.servlet.http.HttpServletResponse;
+import org.jdom2.Element;
 import com.openexchange.config.ConfigTools;
 import com.openexchange.config.cascade.ConfigView;
 import com.openexchange.config.cascade.ConfigViewFactory;
@@ -39,11 +41,13 @@ import com.openexchange.dav.DAVFactory;
 import com.openexchange.dav.DAVProtocol;
 import com.openexchange.dav.DAVUserAgent;
 import com.openexchange.dav.PreconditionException;
+import com.openexchange.dav.Privilege;
 import com.openexchange.dav.Tools;
 import com.openexchange.dav.internal.FolderUpdate;
 import com.openexchange.dav.mixins.ACL;
 import com.openexchange.dav.mixins.ACLRestrictions;
 import com.openexchange.dav.mixins.CTag;
+import com.openexchange.dav.mixins.CurrentUserPrivilegeSet;
 import com.openexchange.dav.mixins.Invite;
 import com.openexchange.dav.mixins.Principal;
 import com.openexchange.dav.mixins.ShareAccess;
@@ -53,6 +57,7 @@ import com.openexchange.dav.reports.SyncStatus;
 import com.openexchange.exception.OXException;
 import com.openexchange.exception.OXException.IncorrectString;
 import com.openexchange.exception.OXException.ProblematicAttribute;
+import com.openexchange.folderstorage.Folder;
 import com.openexchange.folderstorage.FolderField;
 import com.openexchange.folderstorage.FolderProperty;
 import com.openexchange.folderstorage.FolderService;
@@ -63,12 +68,15 @@ import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.folderstorage.type.PrivateType;
 import com.openexchange.folderstorage.type.SharedType;
 import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.java.Charsets;
 import com.openexchange.user.User;
 import com.openexchange.user.UserService;
 import com.openexchange.webdav.protocol.WebdavPath;
+import com.openexchange.webdav.protocol.WebdavProperty;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
 import com.openexchange.webdav.protocol.WebdavResource;
 import com.openexchange.webdav.protocol.helpers.AbstractResource;
+import com.openexchange.webdav.xml.resources.PropertiesMarshaller;
 
 /**
  * {@link FolderCollection}
@@ -290,7 +298,7 @@ public abstract class FolderCollection<T> extends DAVCollection {
     @Override
     public String getDisplayName() throws WebdavProtocolException {
         Locale locale = factory.getUser().getLocale();
-        String name = null != locale ? folder.getLocalizedName(locale) : folder.getName();
+        String name = null != locale ? folder.getName(locale) : folder.getName();
         String ownerName = SharedType.getInstance().equals(this.folder.getType()) ? getOwnerName() : null;
         if (null != ownerName && 0 < ownerName.length()) {
             return String.format("%s (%s)", name, ownerName);
@@ -342,6 +350,14 @@ public abstract class FolderCollection<T> extends DAVCollection {
         }
     }
 
+    @Override
+    public void create() throws WebdavProtocolException {
+        if (exists()) {
+            throw WebdavProtocolException.Code.DIRECTORY_ALREADY_EXISTS.create(getUrl(), HttpServletResponse.SC_METHOD_NOT_ALLOWED);
+        }
+        super.create();
+    }
+
     @Override
     public void delete() throws WebdavProtocolException {
         internalDelete();
@@ -474,4 +490,71 @@ public abstract class FolderCollection<T> extends DAVCollection {
         return null != owner ? owner.getDisplayName() : null;
     }
 
+    /**
+     * Gets a value indicating whether the underlying folder supports a certain capability or not, as indicated through
+     * {@link Folder#getSupportedCapabilities()}.
+     * 
+     * @param folderCapability The capability to check support for
+     * @return <code>true</code> if support is indicated for the capability, <code>false</code>, otherwise
+     */
+    public boolean supports(String folderCapability) {
+        if (null != folder) {
+            Set<String> supportedCapabilities = folder.getSupportedCapabilities();
+            return null != supportedCapabilities && supportedCapabilities.contains(folderCapability);
+        }
+        return false;
+    }
+
+    /**
+     * Checks that a specific privilege is granted to the current user, by checking the <code>DAV:current-user-privilege-set</code>
+     * property mixin from the collection, and throws an appropriate exception in case it is missing.
+     * <p/>
+     * Does nothing if no <code>DAV:current-user-privilege-set</code> is contained.
+     * 
+     * @param privilege The privilege to check for
+     * @throws PreconditionException - In case the privilege is missing
+     */
+    public void requirePrivilege(Privilege privilege) throws PreconditionException {
+        /*
+         * get applicable DAV:current-user-privilege-set element
+         */
+        WebdavProperty property;
+        try {
+            property = getProperty(CurrentUserPrivilegeSet.PROPERTY_NAMESPACE, CurrentUserPrivilegeSet.PROPERTY_NAME);
+        } catch (WebdavProtocolException e) {
+            LOG.warn("Unexpected error getting DAV:current-user-privilege-set property from {}, cannot check privileges.", getUrl(), e);
+            return;
+        }       
+        if (null == property) {
+            return;
+        }
+        PropertiesMarshaller marshaller = new PropertiesMarshaller(factory.getURLPrefix(), Charsets.UTF_8_NAME);
+        Element currentUserPrivilegeSetElement = marshaller.marshalProperty(property, getProtocol());
+        /*
+         * check that required privilege is contained
+         */
+        List<Element> children = currentUserPrivilegeSetElement.getChildren();
+        if (null != children) {
+            for (Element child : children) {
+                if (DAVProtocol.DAV_NS.getURI().equals(child.getNamespaceURI()) && "privilege".equals(child.getName())) {
+                    List<Element> privilegeChildren = child.getChildren();
+                    if (null != privilegeChildren) {
+                        for (Element privilegeChild : privilegeChildren) {
+                            if (privilegeChild.getName().equals(privilege.getName())) {
+                                return;
+                            }
+                        }
+                    }
+                }
+            }
+        }
+        Element preconditionElement = new Element("need-privileges")
+            .addContent(new Element("resource")
+                .addContent(new Element("href").addContent(marshaller.marshalHREF(getUrl(), true)))
+                .addContent(new Element("privilege").addContent(new Element(privilege.getName())))
+            )
+        ;
+        throw new PreconditionException(OXException.general("Insufficient privileges"), preconditionElement, getUrl(), HttpServletResponse.SC_FORBIDDEN);
+    }
+
 }
